##############
DynamoDB class
##############

.. currentmodule:: ddbmock.database.db

.. autoclass:: DynamoDB

Constructors
============

__init__
--------

.. automethod:: DynamoDB.__init__

Batch data manipulations
========================

get_batch
---------

.. automethod:: DynamoDB.get_batch

write_batch
-----------

.. automethod:: DynamoDB.write_batch

Database management
===================

list_tables
-----------

.. automethod:: DynamoDB.list_tables

create_table
------------

.. automethod:: DynamoDB.create_table

delete_table
------------

.. automethod:: DynamoDB.delete_table

get_table
---------

.. automethod:: DynamoDB.get_table

hard_reset
----------

.. automethod:: DynamoDB.hard_reset
